class ItemsController < ApplicationController
  before_action :set_item, only: [:show, :edit, :update, :destroy]

  # GET /items
  # GET /items.json
  def index
    @items = Item.get_page(params[:page], params[:q], @user)
  end

  # GET /items/1
  # GET /items/1.json
  def show
  end

  # GET /items/new
  def new
    @item = Item.new
  end

  # GET /items/1/edit
  def edit
  end

  # POST /items
  # POST /items.json
  def create
    params.require(:item).permit(:name, :barcode, :price, :image)
    @item = Item.new(
      name: params[:item][:name], 
      barcode: params[:item][:barcode], 
      price: params[:item][:price])
    respond_to do |format|
      if @item.save
        format.html { redirect_to @item, notice: 'Item was successfully created.' }
        format.json { render :show, status: :created, location: @item }
        unless params[:item][:image].nil?
          Image.saveFile params[:item][:image], @item
        end
      else
        format.html { render :new }
        format.json { render json: @item.errors, status: :unprocessable_entity }
      end
    end
  end

  # PATCH/PUT /items/1
  # PATCH/PUT /items/1.json
  def update
    params.require(:item).permit(:name, :barcode, :price, :image)
    respond_to do |format|
      if @item.update(
          name: params[:item][:name],
          barcode: params[:item][:barcode],
          price: params[:item][:price])
        format.html { redirect_to @item, notice: 'Item was successfully updated.' }
        format.json { render :show, status: :ok, location: @item }
        unless params[:item][:image].nil?
          Image.saveFile params[:item][:image], @item
        end
      else
        format.html { render :edit }
        format.json { render json: @item.errors, status: :unprocessable_entity }
      end
    end
  end

  # DELETE /items/1
  # DELETE /items/1.json
  def destroy
    @item.destroy
    respond_to do |format|
      format.html { redirect_to items_url, notice: 'Item was successfully destroyed.' }
      format.json { head :no_content }
    end
  end

  def download
    @image = Image.find(params[:id])
    send_file @image.path, type: @image.mime, disposition: :inline
  end

  def borrow
    item = Item.find params[:item]
    user = User.find params[:user]
    Borrow.borrow item, user
    @items = Item.get_page(params[:page], params[:q], @user)
    redirect_to :index
  end

  def return
    item = Item.find params[:item]
    user = User.find params[:user]
    Borrow.return item, user
    @items = Item.get_page(params[:page], params[:q], @user)
    redirect_to :index
  end

  private
    # Use callbacks to share common setup or constraints between actions.
    def set_item
      @item = Item.find(params[:id])
    end

    # Never trust parameters from the scary internet, only allow the white list through.
    def item_params
      params.require(:item).permit(:name, :barcode, :price)
    end
end
